@@ -15,11 +15,11 @@
 import os
 import subprocess
 
-from oslo_utils import encodeutils
 import six
 from six.moves import configparser
 
 from rally.common import logging
+from rally.utils import encodeutils
 
 
 LOG = logging.getLogger(__name__)
@@ -58,8 +58,9 @@ def check_output(*args, **kwargs):
         LOG.error("Error output: '%s'" % encodeutils.safe_decode(exc.output))
         raise
 
+    output = encodeutils.safe_decode(output)
     if output and debug_output:
-        LOG.debug("Subprocess output: '%s'" % encodeutils.safe_decode(output))
+        LOG.debug("Subprocess output: '%s'" % output)
 
     return output
 
