@@ -213,7 +213,8 @@ class TaskTestCase(unittest.TestCase):
         config = utils.TaskConfig(None)
         with self.assertRaises(utils.RallyCliError) as err:
             rally("task start --task %s" % config.filename)
-        self.assertIn("Input task is empty", err.exception.output)
+        self.assertIn("Task config is invalid: `It is empty`",
+                      err.exception.output)
 
     def test_results(self):
         rally = utils.Rally()
@@ -1419,8 +1420,7 @@ class HookTestCase(unittest.TestCase):
         self.assertEqual(
             expected,
             sorted(hook_results,
-                   key=lambda i: list(
-                       i["config"]["trigger"].values())[0]["unit"]))
+                   key=lambda i: i["config"]["trigger"]["args"]["unit"]))
         self._assert_results_time(hook_results)
 
     def test_import_hook_result(self):
